@@ -11,6 +11,7 @@ from cameo_claw.cameo_claw import it_chunk
 
 from pydantic import BaseModel
 import polars as pl
+import pandas as pd
 
 app = FastAPI()
 app.add_middleware(CORSMiddleware,
@@ -48,7 +49,7 @@ async def it_streaming(i: ItemUrlFilter):
 
 def write_csv_header_to_gz(i):
     r = requests.get(i.lst_url[0], verify=False)
-    df = pl.read_csv(r.content)
+    df = pd.read_csv(BytesIO(r.content), compression='gzip')
     bytesio_gz = BytesIO()
     with gzip.open(bytesio_gz, 'wb') as f:
         f.write((','.join(df.columns) + '\n').encode('utf-8'))
@@ -72,5 +73,5 @@ async def streaming_get(md5_hex):
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20427):
+def server(host='0.0.0.0', int_port=20429):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
